@@ -3,7 +3,7 @@ use warnings;
 
 package HTTP::BrowserDetect;
 {
-  $HTTP::BrowserDetect::VERSION = '1.61';
+  $HTTP::BrowserDetect::VERSION = '1.62';
 }
 
 use vars qw(@ALL_TESTS);
@@ -709,7 +709,7 @@ sub _test {
     $self->_os_tests;
     $self->_robot_tests;
 
-    return unless $self->robot;
+    return undef unless $self->robot;
 
 }
 
@@ -1012,7 +1012,7 @@ sub os_version {
 
 sub browser_string {
     my ( $self ) = _self_or_default( @_ );
-    return unless defined $self->{user_agent};
+    return undef unless defined $self->{user_agent};
 
     return 'Netscape'      if $self->netscape;
     return 'IceWeasel'     if $self->iceweasel;
@@ -1036,12 +1036,12 @@ sub browser_string {
     return 'puf'           if $self->puf;
     return 'NetFront'      if $self->netfront;
     return 'Nintendo 3DS'  if $self->n3ds;
-    return;
+    return undef;
 }
 
 sub os_string {
     my ( $self ) = _self_or_default( @_ );
-    return unless defined $self->{user_agent};
+    return undef unless defined $self->{user_agent};
 
     return 'Win95'                       if $self->win95;
     return 'Win98'                       if $self->win98;
@@ -1065,7 +1065,7 @@ sub os_string {
     return 'Mac OS X'                    if $self->macosx;
     return 'Mac'                         if $self->mac;
     return 'OS2'                         if $self->os2;
-    return;
+    return undef;
 }
 
 sub realplayer {
@@ -1453,7 +1453,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 1.61
+version 1.62
 
 =head1 SYNOPSIS
 
@@ -1953,6 +1953,8 @@ Aran Deltac
 
 yeahoffline
 
+David Ihnen
+
 =head1 TO DO
 
 The C<_engine()> method currently only handles Gecko and Trident.  It needs to
